import React, { useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";
import { useForm, Controller } from "react-hook-form";

const EditUser = ({ users, setUsers }) => {
  const { id } = useParams();
  const navigate = useNavigate();

  const {
    control,
    handleSubmit,
    reset,
    formState: { errors },
  } = useForm({
    defaultValues: {
      name: "",
      email: "",
      phone: "",
      website: "",
    },
  });

  useEffect(() => {
    if (id !== "new") {
      const existingUser = users.find((user) => user.id === parseInt(id));
      if (existingUser) {
        reset(existingUser); // Populate form with the existing user data
      }
    }
  }, [id, users, reset]);

  const onSubmit = (data) => {
    if (id === "new") {
      const newUser = { ...data, id: users.length + 1 }; // Generate a new ID
      setUsers([...users, newUser]);
      alert("User added successfully!");
    } else {
      setUsers(
        users.map((user) =>
          user.id === parseInt(id) ? { ...data, id: user.id } : user
        )
      );
      alert("User updated successfully!");
    }
    navigate("/");
  };

  const handleDelete = () => {
    setUsers(users.filter((user) => user.id !== parseInt(id)));
    alert(`User with ID ${id} deleted.`);
    navigate("/");
  };

  return (
    <div className="form-container">
      <h1>{id === "new" ? "Add" : "Edit"} User</h1>
      <form onSubmit={handleSubmit(onSubmit)}>
        {/* Form Fields */}
        <div className="form-group">
          <label>Name</label>
          <Controller
            name="name"
            control={control}
            rules={{ required: "Name is required." }}
            render={({ field }) => (
              <input
                {...field}
                className={errors.name ? "error-input" : ""}
              />
            )}
          />
          {errors.name && <span>{errors.name.message}</span>}
        </div>
        <div className="form-group">
          <label>Email</label>
          <Controller
            name="email"
            control={control}
            rules={{
              required: "Email is required.",
              pattern: {
                value: /^[^\s@]+@[^\s@]+\.[^\s@]+$/,
                message: "Invalid email format.",
              },
            }}
            render={({ field }) => (
              <input
                {...field}
                className={errors.email ? "error-input" : ""}
              />
            )}
          />
          {errors.email && <span>{errors.email.message}</span>}
        </div>
        <div className="form-group">
          <label>Phone</label>
          <Controller
            name="phone"
            control={control}
            rules={{
              required: "Phone number is required.",
              pattern: {
                value: /^[0-9]{10}$/,
                message: "Phone number must be 10 digits.",
              },
            }}
            render={({ field }) => (
              <input
                {...field}
                className={errors.phone ? "error-input" : ""}
              />
            )}
          />
          {errors.phone && <span>{errors.phone.message}</span>}
        </div>
        <div className="form-group">
          <label>Website</label>
          <Controller
            name="website"
            control={control}
            rules={{
              pattern: {
                value: /^(https?:\/\/)?([\w\d\-_]+\.)+[\w\d\-_]+(\/[\w\d\-_.?&=]*)*\/?$/,
                message: "Invalid website URL.",
              },
            }}
            render={({ field }) => (
              <input
                {...field}
                className={errors.website ? "error-input" : ""}
              />
            )}
          />
          {errors.website && <span>{errors.website.message}</span>}
        </div>
        <button type="submit" className="submit-button">
          Save
        </button>
      </form>
      <div className="button-container">
        <button className="home-button" onClick={() => navigate("/")}>
          Return to Home
        </button>
        {id !== "new" && (
          <button className="delete-button" onClick={handleDelete}>
            Delete User
          </button>
        )}
      </div>
    </div>
  );
};

export default EditUser;
